@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""This module provides an interface for the rsync utility"""
+"""This module provides an interface for the rsync utility."""
 
 import subprocess
 import time
